==> LoadL-3.4.0.5-0.RH4-X86.3.4.X.tar.gz: opt/ibmll/LoadL/full/samples/llres/llreshist.pl <==
#!/usr/bin/perl
# "@(#)03   1.2   src/ll/samples/llres/llreshist.pl, ll.api, ll_rven, rven0635b 8/1/06 17:23:39";
#
# Parse a LoadLeveler reservation history file and
# display the history information in a format similar
# that of llqres -l

$width = 20;
$buf = " " x ($width+2);

# Read each line from either stdin or from a list of files
while (<>) {
    ( $res_id, $creation_time, $owner, $group,
      $req_start_time, $act_start_time,
      $req_duration, $act_duration,
      $end_time, $shared, $rm_on_idle,
      $users, $groups, $num_nodes, $nodes, 
      $num_bg_cnodes, $bg_connection, $bg_shape, $num_bg_bps, $bg_bps
    ) = split /!/ ;

	# Print a header containing the reservation id
    print "=" x 15, " Reservation ", $res_id, " ", "=" x 15, "\n";

	# Print each field from the history file on its own line
    printf "%${width}s: ", "Creation Time";
    $tm_str = localtime($creation_time);
    print $tm_str, "\n";

    printf "%${width}s: ", "Owner";
    print $owner, "\n";

    printf "%${width}s: ", "Group";
    print $group, "\n";

    printf "%${width}s: ", "Requested Start Time";
    $tm_str = localtime($req_start_time);
    print $tm_str, "\n";

	# Actual Start Time == 0 is an indication the
	# reservation never became active (it was removed
	# while still in WAITING state).
    printf "%${width}s: ", "Actual Start Time";
    if ($act_start_time > 0) {
        $tm_str = localtime($act_start_time);
    } else {
        $tm_str = 0;
    }
    print $tm_str, "\n";

    printf "%${width}s: ", "Requested Duration";
    print $req_duration, " seconds (", duration_to_str($req_duration), ")\n";

    printf "%${width}s: ", "Actual Duration";
    print $act_duration, " seconds (", duration_to_str($act_duration), ")\n";

    printf "%${width}s: ", "End Time";
    $tm_str = localtime($end_time);
    print $tm_str, "\n";

    printf "%${width}s: ", "Shared Mode";
    print $shared, "\n";

    printf "%${width}s: ", "Remove On Idle Mode";
    print $rm_on_idle, "\n";


	# For the user and group lists, print the number of
	# users/groups in the list, then print each user/group
	# on a separate line.

    printf "%${width}s: ", "Users";
    @user_list = split /,/, $users;
    print @user_list."\n";
    printf ( "$buf%s\n" x @user_list, @user_list);

    printf "%${width}s: ", "Groups";
    @group_list = split /,/, $groups;
    print @group_list."\n";
    printf ( "$buf%s\n" x @group_list, @group_list);

    printf "%${width}s: ", "Nodes";
    print $num_nodes, "\n";


	# Print each hostname on its own line.
	# The long_hostname subroutine will convert the short
	# name from the history file into the machine's full name.

    chomp $nodes;   # The \n is still there, so get rid of it
    @hostlist = long_hostname ( split ( /,/, $nodes ) );
    printf ( "$buf%s\n" x @hostlist, @hostlist);

	# Print BG reservation info

    next if ($num_bg_cnodes == 0);

    printf "%${width}s: ", "BG C-nodes";
    print $num_bg_cnodes, "\n";

    printf "%${width}s: ", "BG Connection";
    print $bg_connection, "\n";

    printf "%${width}s: ", "BG Shape";
    print $bg_shape, "\n";

    printf "%${width}s: ", "BG BPs";
    print $num_bg_bps, "\n";

	# Print each BP on its own line.
    chomp $bg_bps;   # The \n is still there, so get rid of it
    @bplist = split ( /,/, $bg_bps );
    printf ( "$buf%s\n" x @bplist, @bplist);

}

# long_hostname
#
# The reservation history file prints the short hostnames
# of the reserved machines.  For display purposes, get the
# full hostnames.
sub long_hostname {
    use Net::hostent;
    for $host (@_) {
    my $he = gethost($host);
        $host = $he->name;
    }
    @_;
}


# duration_to_str
#
# The reservation history file prints the requested duration
# and actual duration in seconds.  Convert that value here
# to a more user-friendly string.
sub duration_to_str {
    use integer;
    my $dur = $_[0];
    my $days = $dur / (24 * 60 * 60);
    my $hours =  ($dur / 3600) % 24;
    my $minutes = ($dur / 60) % 60;
    my $seconds = $dur % 60;
    my $str = sprintf("%d days %02d:%02d:%02d", $days, $hours, $minutes, $seconds);
}

==> LoadL-3.5.0.3-0.RH4-X86.3.5.X.tar.gz: opt/ibmll/LoadL/full/samples/llres/llreshist.pl <==
#!/usr/bin/perl
# "@(#)03   1.4   src/ll/samples/llres/llreshist.pl, ll.api, ll_rsat, rsat0838a 1/11/08 03:54:25";
#
# Parse a LoadLeveler reservation history file and
# display the history information in a format similar
# that of llqres -l

$width = 20;
$buf = " " x ($width+2);

# Read each line from either stdin or from a list of files
while (<>) {
    ( $res_id, $creation_time, $owner, $group,
      $req_start_time, $act_start_time,
      $req_duration, $act_duration,
      $end_time, 
      $reservation_type, $expiration,
      $shared, $rm_on_idle, $binding_method,
      $users, $groups, $num_nodes, $nodes, 
      $num_bg_cnodes, $bg_connection, $bg_shape, $num_bg_bps, $bg_bps, $bg_partition
    ) = split /!/ ;

	# Print a header containing the reservation id
    print "=" x 15, " Reservation ", $res_id, " ", "=" x 15, "\n";

	# Print each field from the history file on its own line
    printf "%${width}s: ", "Creation Time";
    $tm_str = localtime($creation_time);
    print $tm_str, "\n";

    printf "%${width}s: ", "Owner";
    print $owner, "\n";

    printf "%${width}s: ", "Group";
    print $group, "\n";

    printf "%${width}s: ", "Requested Start Time";
    $tm_str = localtime($req_start_time);
    print $tm_str, "\n";

	# Actual Start Time == 0 is an indication the
	# reservation never became active (it was removed
	# while still in WAITING state).
    printf "%${width}s: ", "Actual Start Time";
    if ($act_start_time > 0) {
        $tm_str = localtime($act_start_time);
    } else {
        $tm_str = 0;
    }
    print $tm_str, "\n";

    printf "%${width}s: ", "Requested Duration";
    print $req_duration, " seconds (", duration_to_str($req_duration), ")\n";

    printf "%${width}s: ", "Actual Duration";
    print $act_duration, " seconds (", duration_to_str($act_duration), ")\n";

    if ($reservation_type eq "ONE_TIME") {
    	printf "%${width}s: ", "Expiration";
      print "One time reservation, not allowed", "\n";
    }else {
	    printf "%${width}s: ", "Expiration";
	    $tm_str = localtime($expiration);
    	print $tm_str, "\n";
    }
    printf "%${width}s: ", "Actual End Time";
    $tm_str = localtime($end_time);
    print $tm_str, "\n";

    printf "%${width}s: ", "Shared Mode";
    print $shared, "\n";

    printf "%${width}s: ", "Remove On Idle Mode";
    print $rm_on_idle, "\n";

    printf "%${width}s: ", "Binding Method";
    print $binding_method, "\n";

	# For the user and group lists, print the number of
	# users/groups in the list, then print each user/group
	# on a separate line.

    printf "%${width}s: ", "Users";
    @user_list = split /,/, $users;
    print @user_list."\n";
    printf ( "$buf%s\n" x @user_list, @user_list);

    printf "%${width}s: ", "Groups";
    @group_list = split /,/, $groups;
    print @group_list."\n";
    printf ( "$buf%s\n" x @group_list, @group_list);

    printf "%${width}s: ", "Nodes";
    print $num_nodes, "\n";


	# Print each hostname on its own line.
	# The long_hostname subroutine will convert the short
	# name from the history file into the machine's full name.

    chomp $nodes;   # The \n is still there, so get rid of it
    @hostlist = long_hostname ( split ( /,/, $nodes ) );
    printf ( "$buf%s\n" x @hostlist, @hostlist);

	# Print BG reservation info

    next if ($num_bg_cnodes == 0);

    printf "%${width}s: ", "BG C-nodes";
    print $num_bg_cnodes, "\n";

    printf "%${width}s: ", "BG Connection";
    print $bg_connection, "\n";

    printf "%${width}s: ", "BG Shape";
    print $bg_shape, "\n";

    printf "%${width}s: ", "BG BPs";
    print $num_bg_bps, "\n";

	# Print each BP on its own line.
    chomp $bg_bps;   # The \n is still there, so get rid of it
    @bplist = split ( /,/, $bg_bps );
    printf ( "$buf%s\n" x @bplist, @bplist);

    printf "%${width}s: ", "BG Partition";
    print $bg_partition, "\n";

}

# long_hostname
#
# The reservation history file prints the short hostnames
# of the reserved machines.  For display purposes, get the
# full hostnames.
sub long_hostname {
    use Net::hostent;
    for $host (@_) {
    my $he = gethost($host);
        $host = $he->name;
    }
    @_;
}


# duration_to_str
#
# The reservation history file prints the requested duration
# and actual duration in seconds.  Convert that value here
# to a more user-friendly string.
sub duration_to_str {
    use integer;
    my $dur = $_[0];
    my $days = $dur / (24 * 60 * 60);
    my $hours =  ($dur / 3600) % 24;
    my $minutes = ($dur / 60) % 60;
    my $seconds = $dur % 60;
    my $str = sprintf("%d days %02d:%02d:%02d", $days, $hours, $minutes, $seconds);
}
